"""Autogenerated models for xcresulttool."""

import datetime
import sys
from typing import Any, Optional
import urllib.parse


# pylint: disable=too-many-lines
# pylint: disable=invalid-name


class XcresultObject:
    """Generated from xcresulttool format description."""


# Defined Type: Bool -> bool


# Defined Type: Data -> bytes


# Defined Type: Date -> datetime.datetime


# Defined Type: Double -> float


# Defined Type: Int -> int


# Defined Type: Int16 -> int


# Defined Type: Int32 -> int


# Defined Type: Int64 -> int


# Defined Type: Int8 -> int


# Defined Type: String -> str


# Defined Type: UInt16 -> int


# Defined Type: UInt32 -> int


# Defined Type: UInt64 -> int


# Defined Type: UInt8 -> int


# Defined Type: URL -> str


# Defined Type: Array -> Array


class ActionPlatformRecord(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionPlatformRecord
      * Kind: object
      * Properties:
        + identifier: String
        + userDescription: String
    """

    identifier: str
    userDescription: str


class ActionSDKRecord(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionSDKRecord
      * Kind: object
      * Properties:
        + name: String
        + identifier: String
        + operatingSystemVersion: String
        + isInternal: Bool
    """

    name: str
    identifier: str
    operatingSystemVersion: str
    isInternal: bool


class ActivityLogAnalyzerStep(XcresultObject):
    """Generated from xcresulttool format description.

    - ActivityLogAnalyzerStep
      * Kind: object
      * Properties:
        + parentIndex: Int
    """

    parentIndex: int


class ActivityLogSectionAttachment(XcresultObject):
    """Generated from xcresulttool format description.

    - ActivityLogSectionAttachment
      * Kind: object
      * Properties:
        + identifier: String
        + majorVersion: UInt8
        + minorVersion: UInt8
        + data: Data
    """

    identifier: str
    majorVersion: int
    minorVersion: int
    data: bytes


class DocumentLocation(XcresultObject):
    """Generated from xcresulttool format description.

    - DocumentLocation
      * Kind: object
      * Properties:
        + url: String
        + concreteTypeName: String
    """

    url: str
    concreteTypeName: str

    @staticmethod
    def empty() -> "DocumentLocation":
        """Create a new "empty" instance

        :returns: A new instance
        """
        instance = DocumentLocation.__new__(DocumentLocation)
        instance.concreteTypeName = ""
        instance.url = "file://#CharacterRangeLen=0&EndingColumnNumber=0&EndingLineNumber=0&StartingColumnNumber=0&StartingLineNumber=0"
        return instance

    @property
    def path(self) -> str:
        """Get the path of the document if set, empty string otherwise.

        :returns: The path of the document
        """
        return self.url.split("#", maxsplit=1)[0].replace("file://", "")

    @property
    def location(self) -> str:
        """Get the raw location inside the document

        :returns: The location inside the document
        """
        return self.url.split("#")[1]

    @property
    def location_details(self) -> dict[str, list[str]]:
        """Get the raw location parameters inside the document

        :returns: The location parametersinside the document
        """
        return urllib.parse.parse_qs(self.location)

    def _get_property(self, key: str, *, offset: int = 0) -> int | None:
        """Get a property from the location details.

        :param key: The key for the property
        :param offset: Any offset to apply to the value (if found)

        :returns: The property as an int value if found, None otherwise
        """
        value = self.location_details.get(key)
        if value is None:
            return None
        return int(value[0]) + offset

    @property
    def character_range_length(self) -> int:
        """Get the character range length

        :returns: The character range length
        """
        return int(self.location_details["CharacterRangeLen"][0]) + 1

    @property
    def character_range_location(self) -> int | None:
        """Get the character range location if set, None otherwise

        :returns: The character range location
        """
        return self._get_property("CharacterRangeLoc")

    @property
    def ending_column_number(self) -> int | None:
        """Get the ending column number if set, None otherwise

        :returns: The ending column number
        """
        return self._get_property("EndingColumnNumber", offset=1)

    @property
    def ending_line_number(self) -> int | None:
        """Get the ending line number if set, None otherwise

        :returns: The ending line number
        """
        return self._get_property("EndingLineNumber", offset=1)

    @property
    def location_encoding(self) -> int | None:
        """Get the location encoding if set, None otherwise

        :returns: The location encoding
        """
        return self._get_property("LocationEncoding")

    @property
    def starting_column_number(self) -> int | None:
        """Get the starting column number if set, None otherwise

        :returns: The starting column number
        """
        return self._get_property("StartingColumnNumber", offset=1)

    @property
    def starting_line_number(self) -> int | None:
        """Get the starting line number if set, None otherwise

        :returns: The starting line number
        """
        return self._get_property("StartingLineNumber", offset=1)


class EntityIdentifier(XcresultObject):
    """Generated from xcresulttool format description.

    - EntityIdentifier
      * Kind: object
      * Properties:
        + entityName: String
        + containerName: String
        + entityType: String
        + sharedState: String
    """

    entityName: str
    containerName: str
    entityType: str
    sharedState: str


class ObjectID(XcresultObject):
    """Generated from xcresulttool format description.

    - ObjectID
      * Kind: object
      * Properties:
        + hash: String
    """

    hash: str


class SortedKeyValueArrayPair(XcresultObject):
    """Generated from xcresulttool format description.

    - SortedKeyValueArrayPair
      * Kind: object
      * Properties:
        + key: String
        + value: SchemaSerializable
    """

    key: str
    value: Any


class TestDocumentation(XcresultObject):
    """Generated from xcresulttool format description.

    - TestDocumentation
      * Kind: object
      * Properties:
        + content: String
        + format: String
    """

    content: str
    format: str


class TypeDefinition(XcresultObject):
    """Generated from xcresulttool format description.

    - TypeDefinition
      * Kind: object
      * Properties:
        + name: String
        + supertype: TypeDefinition?
    """

    name: str
    supertype: Optional["TypeDefinition"]


class ActionAbstractTestSummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionAbstractTestSummary
      * Kind: object
      * Properties:
        + name: String?
    """

    name: str | None


class ActionDeviceRecord(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionDeviceRecord
      * Kind: object
      * Properties:
        + name: String
        + isConcreteDevice: Bool
        + operatingSystemVersion: String
        + operatingSystemVersionWithBuildNumber: String
        + nativeArchitecture: String
        + modelName: String
        + modelCode: String
        + modelUTI: String
        + identifier: String
        + isWireless: Bool
        + cpuKind: String
        + cpuCount: Int?
        + cpuSpeedInMHz: Int?
        + busSpeedInMHz: Int?
        + ramSizeInMegabytes: Int?
        + physicalCPUCoresPerPackage: Int?
        + logicalCPUCoresPerPackage: Int?
        + platformRecord: ActionPlatformRecord
    """

    name: str
    isConcreteDevice: bool
    operatingSystemVersion: str
    operatingSystemVersionWithBuildNumber: str
    nativeArchitecture: str
    modelName: str
    modelCode: str
    modelUTI: str
    identifier: str
    isWireless: bool
    cpuKind: str
    cpuCount: int | None
    cpuSpeedInMHz: int | None
    busSpeedInMHz: int | None
    ramSizeInMegabytes: int | None
    physicalCPUCoresPerPackage: int | None
    logicalCPUCoresPerPackage: int | None
    platformRecord: ActionPlatformRecord


class ActionTestNoticeSummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestNoticeSummary
      * Kind: object
      * Properties:
        + message: String?
        + fileName: String
        + lineNumber: Int
        + timestamp: Date?
    """

    message: str | None
    fileName: str
    lineNumber: int
    timestamp: datetime.datetime | None


class ActionTestPerformanceMetricSummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestPerformanceMetricSummary
      * Kind: object
      * Properties:
        + displayName: String
        + unitOfMeasurement: String
        + measurements: [Double]
        + identifier: String?
        + baselineName: String?
        + baselineAverage: Double?
        + maxPercentRegression: Double?
        + maxPercentRelativeStandardDeviation: Double?
        + maxRegression: Double?
        + maxStandardDeviation: Double?
        + polarity: String?
    """

    displayName: str
    unitOfMeasurement: str
    measurements: list[float]
    identifier: str | None
    baselineName: str | None
    baselineAverage: float | None
    maxPercentRegression: float | None
    maxPercentRelativeStandardDeviation: float | None
    maxRegression: float | None
    maxStandardDeviation: float | None
    polarity: str | None


class ActionTestRepetitionPolicySummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestRepetitionPolicySummary
      * Kind: object
      * Properties:
        + iteration: Int?
        + totalIterations: Int?
        + repetitionMode: String?
    """

    iteration: int | None
    totalIterations: int | None
    repetitionMode: str | None


class ActionsInvocationMetadata(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionsInvocationMetadata
      * Kind: object
      * Properties:
        + creatingWorkspaceFilePath: String
        + uniqueIdentifier: String
        + schemeIdentifier: EntityIdentifier?
    """

    creatingWorkspaceFilePath: str
    uniqueIdentifier: str
    schemeIdentifier: EntityIdentifier | None


class ActivityLogAnalyzerControlFlowStepEdge(XcresultObject):
    """Generated from xcresulttool format description.

    - ActivityLogAnalyzerControlFlowStepEdge
      * Kind: object
      * Properties:
        + startLocation: DocumentLocation?
        + endLocation: DocumentLocation?
    """

    startLocation: DocumentLocation | None
    endLocation: DocumentLocation | None


class ActivityLogAnalyzerEventStep(ActivityLogAnalyzerStep):
    """Generated from xcresulttool format description.

    - ActivityLogAnalyzerEventStep
      * Supertype: ActivityLogAnalyzerStep
      * Kind: object
      * Properties:
        + title: String
        + location: DocumentLocation?
        + description: String
        + callDepth: Int
    """

    title: str
    location: DocumentLocation | None
    description: str
    callDepth: int


class ActivityLogMessageAnnotation(XcresultObject):
    """Generated from xcresulttool format description.

    - ActivityLogMessageAnnotation
      * Kind: object
      * Properties:
        + title: String
        + location: DocumentLocation?
    """

    title: str
    location: DocumentLocation | None


class ArchiveInfo(XcresultObject):
    """Generated from xcresulttool format description.

    - ArchiveInfo
      * Kind: object
      * Properties:
        + path: String?
    """

    path: str | None


class ConsoleLogItemLogData(XcresultObject):
    """Generated from xcresulttool format description.

    - ConsoleLogItemLogData
      * Kind: object
      * Properties:
        + message: String?
        + subsystem: String?
        + category: String?
        + library: String?
        + format: String?
        + backtrace: String?
        + pid: Int32
        + processName: String?
        + sessionUUID: String?
        + tid: UInt64
        + messageType: UInt8
        + senderImagePath: String?
        + senderImageUUID: String?
        + senderImageOffset: UInt64
        + unixTimeInterval: Double
        + timeZone: String?
    """

    message: str | None
    subsystem: str | None
    category: str | None
    library: str | None
    format: str | None
    backtrace: str | None
    pid: int
    processName: str | None
    sessionUUID: str | None
    tid: int
    messageType: int
    senderImagePath: str | None
    senderImageUUID: str | None
    senderImageOffset: int
    unixTimeInterval: float
    timeZone: str | None


class IssueSummary(XcresultObject):
    """Generated from xcresulttool format description.

    - IssueSummary
      * Kind: object
      * Properties:
        + issueType: String
        + message: String
        + producingTarget: String?
        + documentLocationInCreatingWorkspace: DocumentLocation?
    """

    issueType: str
    message: str
    producingTarget: str | None
    documentLocationInCreatingWorkspace: DocumentLocation | None

    def pretty_message(self, path_prefix: str | None) -> str:
        """Format the message nicely for review.

        :param path_prefix: Any path prefix to remove

        :returns: A pretty message
        """
        if self.documentLocationInCreatingWorkspace is None:
            return f"* [ERROR] {self.message}"

        relative_path = self.documentLocationInCreatingWorkspace.path

        if path_prefix:
            relative_path = relative_path.replace(path_prefix, "")

        return f"* [ERROR] {self.message}\n  Found in {relative_path}:{self.documentLocationInCreatingWorkspace.starting_line_number}:{self.documentLocationInCreatingWorkspace.starting_column_number}"


class IssueTrackingMetadata(XcresultObject):
    """Generated from xcresulttool format description.

    - IssueTrackingMetadata
      * Kind: object
      * Properties:
        + identifier: String
        + url: URL?
        + comment: String?
        + summary: String
    """

    identifier: str
    url: str | None
    comment: str | None
    summary: str


class Reference(XcresultObject):
    """Generated from xcresulttool format description.

    - Reference
      * Kind: object
      * Properties:
        + id: String
        + targetType: TypeDefinition?
    """

    id: str
    targetType: TypeDefinition | None


class ResultMetrics(XcresultObject):
    """Generated from xcresulttool format description.

    - ResultMetrics
      * Kind: object
      * Properties:
        + analyzerWarningCount: Int
        + errorCount: Int
        + testsCount: Int
        + testsFailedCount: Int
        + testsSkippedCount: Int
        + warningCount: Int
        + totalCoveragePercentage: Double?
    """

    analyzerWarningCount: int
    errorCount: int
    testsCount: int
    testsFailedCount: int
    testsSkippedCount: int
    warningCount: int
    totalCoveragePercentage: float | None


class SortedKeyValueArray(XcresultObject):
    """Generated from xcresulttool format description.

    - SortedKeyValueArray
      * Kind: object
      * Properties:
        + storage: [SortedKeyValueArrayPair]
    """

    storage: list[SortedKeyValueArrayPair]


class SourceCodeLocation(XcresultObject):
    """Generated from xcresulttool format description.

    - SourceCodeLocation
      * Kind: object
      * Properties:
        + filePath: String?
        + lineNumber: Int?
    """

    filePath: str | None
    lineNumber: int | None


class TestParameter(XcresultObject):
    """Generated from xcresulttool format description.

    - TestParameter
      * Kind: object
      * Properties:
        + label: String
        + name: String?
        + typeName: String?
        + fullyQualifiedTypeName: String?
    """

    label: str
    name: str | None
    typeName: str | None
    fullyQualifiedTypeName: str | None


class TestTag(XcresultObject):
    """Generated from xcresulttool format description.

    - TestTag
      * Kind: object
      * Properties:
        + identifier: String
        + name: String
        + anchors: [String]
    """

    identifier: str
    name: str
    anchors: list[str]


class TestValue(XcresultObject):
    """Generated from xcresulttool format description.

    - TestValue
      * Kind: object
      * Properties:
        + description: String
        + debugDescription: String?
        + typeName: String?
        + fullyQualifiedTypeName: String?
        + label: String?
        + isCollection: Bool
        + children: TestValue?
    """

    description: str
    debugDescription: str | None
    typeName: str | None
    fullyQualifiedTypeName: str | None
    label: str | None
    isCollection: bool
    children: Optional["TestValue"]


class ActionRunDestinationRecord(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionRunDestinationRecord
      * Kind: object
      * Properties:
        + displayName: String
        + targetArchitecture: String
        + targetDeviceRecord: ActionDeviceRecord
        + localComputerRecord: ActionDeviceRecord
        + targetSDKRecord: ActionSDKRecord
    """

    displayName: str
    targetArchitecture: str
    targetDeviceRecord: ActionDeviceRecord
    localComputerRecord: ActionDeviceRecord
    targetSDKRecord: ActionSDKRecord


class ActionTestAttachment(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestAttachment
      * Kind: object
      * Properties:
        + uniformTypeIdentifier: String
        + name: String?
        + uuid: String?
        + timestamp: Date?
        + userInfo: SortedKeyValueArray?
        + lifetime: String
        + inActivityIdentifier: Int
        + filename: String?
        + payloadRef: Reference?
        + payloadSize: Int
    """

    uniformTypeIdentifier: str
    name: str | None
    uuid: str | None
    timestamp: datetime.datetime | None
    userInfo: SortedKeyValueArray | None
    lifetime: str
    inActivityIdentifier: int
    filename: str | None
    payloadRef: Reference | None
    payloadSize: int


class ActionTestConfiguration(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestConfiguration
      * Kind: object
      * Properties:
        + values: SortedKeyValueArray
    """

    values: SortedKeyValueArray


class ActionTestSummaryIdentifiableObject(ActionAbstractTestSummary):
    """Generated from xcresulttool format description.

    - ActionTestSummaryIdentifiableObject
      * Supertype: ActionAbstractTestSummary
      * Kind: object
      * Properties:
        + identifier: String?
        + identifierURL: String?
    """

    identifier: str | None
    identifierURL: str | None


class ActivityLogAnalyzerControlFlowStep(ActivityLogAnalyzerStep):
    """Generated from xcresulttool format description.

    - ActivityLogAnalyzerControlFlowStep
      * Supertype: ActivityLogAnalyzerStep
      * Kind: object
      * Properties:
        + title: String
        + startLocation: DocumentLocation?
        + endLocation: DocumentLocation?
        + edges: [ActivityLogAnalyzerControlFlowStepEdge]
    """

    title: str
    startLocation: DocumentLocation | None
    endLocation: DocumentLocation | None
    edges: list[ActivityLogAnalyzerControlFlowStepEdge]


class ActivityLogMessage(XcresultObject):
    """Generated from xcresulttool format description.

    - ActivityLogMessage
      * Kind: object
      * Properties:
        + type: String
        + title: String
        + shortTitle: String?
        + category: String?
        + location: DocumentLocation?
        + annotations: [ActivityLogMessageAnnotation]
    """

    type: str
    title: str
    shortTitle: str | None
    category: str | None
    location: DocumentLocation | None
    annotations: list[ActivityLogMessageAnnotation]


class CodeCoverageInfo(XcresultObject):
    """Generated from xcresulttool format description.

    - CodeCoverageInfo
      * Kind: object
      * Properties:
        + hasCoverageData: Bool
        + reportRef: Reference?
        + archiveRef: Reference?
    """

    hasCoverageData: bool
    reportRef: Reference | None
    archiveRef: Reference | None


class ConsoleLogItem(XcresultObject):
    """Generated from xcresulttool format description.

    - ConsoleLogItem
      * Kind: object
      * Properties:
        + adaptorType: String?
        + kind: String?
        + timestamp: Double
        + content: String
        + logData: ConsoleLogItemLogData?
    """

    adaptorType: str | None
    kind: str | None
    timestamp: float
    content: str
    logData: ConsoleLogItemLogData | None


class SourceCodeSymbolInfo(XcresultObject):
    """Generated from xcresulttool format description.

    - SourceCodeSymbolInfo
      * Kind: object
      * Properties:
        + imageName: String?
        + symbolName: String?
        + location: SourceCodeLocation?
    """

    imageName: str | None
    symbolName: str | None
    location: SourceCodeLocation | None


class TestArgument(XcresultObject):
    """Generated from xcresulttool format description.

    - TestArgument
      * Kind: object
      * Properties:
        + parameter: TestParameter?
        + identifier: String?
        + description: String
        + debugDescription: String?
        + typeName: String?
        + value: TestValue
    """

    parameter: TestParameter | None
    identifier: str | None
    description: str
    debugDescription: str | None
    typeName: str | None
    value: TestValue


class TestAssociatedError(XcresultObject):
    """Generated from xcresulttool format description.

    - TestAssociatedError
      * Kind: object
      * Properties:
        + domain: String?
        + code: Int?
        + userInfo: SortedKeyValueArray?
    """

    domain: str | None
    code: int | None
    userInfo: SortedKeyValueArray | None


class TestExpression(XcresultObject):
    """Generated from xcresulttool format description.

    - TestExpression
      * Kind: object
      * Properties:
        + sourceCode: String
        + value: TestValue?
        + subexpressions: [TestExpression]
    """

    sourceCode: str
    value: TestValue | None
    subexpressions: list["TestExpression"]


class TestFailureIssueSummary(IssueSummary):
    """Generated from xcresulttool format description.

    - TestFailureIssueSummary
      * Supertype: IssueSummary
      * Kind: object
      * Properties:
        + testCaseName: String
    """

    testCaseName: str

    def pretty_message(self, path_prefix: str | None) -> str:
        """Format the message nicely for review.

        :param path_prefix: Any path prefix to remove

        :returns: A pretty message
        """
        # pylint: disable=no-member
        output = f"* [{self.producingTarget}] {self.testCaseName} -> {self.message}"

        documentLocationInCreatingWorkspace = self.documentLocationInCreatingWorkspace

        if (
            documentLocationInCreatingWorkspace is None
            or documentLocationInCreatingWorkspace.path is None
        ):
            return output

        relative_path = documentLocationInCreatingWorkspace.path

        if path_prefix:
            relative_path = relative_path.replace(path_prefix, "")

        return (
            output
            + f"\n  Found in {relative_path}:{documentLocationInCreatingWorkspace.starting_line_number}:{documentLocationInCreatingWorkspace.starting_column_number}"
        )
        # pylint: enable=no-member


class TestIssueSummary(IssueSummary):
    """Generated from xcresulttool format description.

    - TestIssueSummary
      * Supertype: IssueSummary
      * Kind: object
      * Properties:
        + testCaseName: String
    """

    testCaseName: str


class ActionTestActivitySummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestActivitySummary
      * Kind: object
      * Properties:
        + title: String
        + activityType: String
        + uuid: String
        + start: Date?
        + finish: Date?
        + attachments: [ActionTestAttachment]
        + subactivities: [ActionTestActivitySummary]
        + failureSummaryIDs: [String]
        + expectedFailureIDs: [String]
        + warningSummaryIDs: [String]
    """

    title: str
    activityType: str
    uuid: str
    start: datetime.datetime | None
    finish: datetime.datetime | None
    attachments: list[ActionTestAttachment]
    subactivities: list["ActionTestActivitySummary"]
    failureSummaryIDs: list[str]
    expectedFailureIDs: list[str]
    warningSummaryIDs: list[str]


class ActionTestMetadata(ActionTestSummaryIdentifiableObject):
    """Generated from xcresulttool format description.

    - ActionTestMetadata
      * Supertype: ActionTestSummaryIdentifiableObject
      * Kind: object
      * Properties:
        + testStatus: String
        + duration: Double?
        + summaryRef: Reference?
        + performanceMetricsCount: Int
        + failureSummariesCount: Int
        + activitySummariesCount: Int
    """

    testStatus: str
    duration: float | None
    summaryRef: Reference | None
    performanceMetricsCount: int
    failureSummariesCount: int
    activitySummariesCount: int


class ActionTestSummaryGroup(ActionTestSummaryIdentifiableObject):
    """Generated from xcresulttool format description.

    - ActionTestSummaryGroup
      * Supertype: ActionTestSummaryIdentifiableObject
      * Kind: object
      * Properties:
        + duration: Double
        + subtests: [ActionTestSummaryIdentifiableObject]
        + skipNoticeSummary: ActionTestNoticeSummary?
        + summary: String?
        + documentation: [TestDocumentation]
        + trackedIssues: [IssueTrackingMetadata]
        + tags: [TestTag]
    """

    duration: float
    subtests: list[ActionTestSummaryIdentifiableObject]
    skipNoticeSummary: ActionTestNoticeSummary | None
    summary: str | None
    documentation: list[TestDocumentation]
    trackedIssues: list[IssueTrackingMetadata]
    tags: list[TestTag]


class ActivityLogAnalyzerResultMessage(ActivityLogMessage):
    """Generated from xcresulttool format description.

    - ActivityLogAnalyzerResultMessage
      * Supertype: ActivityLogMessage
      * Kind: object
      * Properties:
        + steps: [ActivityLogAnalyzerStep]
        + resultType: String?
        + keyEventIndex: Int
    """

    steps: list[ActivityLogAnalyzerStep]
    resultType: str | None
    keyEventIndex: int


class ActivityLogAnalyzerWarningMessage(ActivityLogMessage):
    """Generated from xcresulttool format description.

    - ActivityLogAnalyzerWarningMessage
      * Supertype: ActivityLogMessage
      * Kind: object
    """


class ActivityLogSection(XcresultObject):
    """Generated from xcresulttool format description.

    - ActivityLogSection
      * Kind: object
      * Properties:
        + domainType: String
        + title: String
        + startTime: Date?
        + duration: Double
        + result: String?
        + location: DocumentLocation?
        + subsections: [ActivityLogSection]
        + messages: [ActivityLogMessage]
        + attachments: [ActivityLogSectionAttachment]
    """

    domainType: str
    title: str
    startTime: datetime.datetime | None
    duration: float
    result: str | None
    location: DocumentLocation | None
    subsections: list["ActivityLogSection"]
    messages: list[ActivityLogMessage]
    attachments: list[ActivityLogSectionAttachment]


class ConsoleLogSection(XcresultObject):
    """Generated from xcresulttool format description.

    - ConsoleLogSection
      * Kind: object
      * Properties:
        + title: String
        + items: [ConsoleLogItem]
    """

    title: str
    items: list[ConsoleLogItem]


class ResultIssueSummaries(XcresultObject):
    """Generated from xcresulttool format description.

    - ResultIssueSummaries
      * Kind: object
      * Properties:
        + analyzerWarningSummaries: [IssueSummary]
        + errorSummaries: [IssueSummary]
        + testFailureSummaries: [TestFailureIssueSummary]
        + warningSummaries: [IssueSummary]
        + testWarningSummaries: [TestIssueSummary]
    """

    analyzerWarningSummaries: list[IssueSummary]
    errorSummaries: list[IssueSummary]
    testFailureSummaries: list[TestFailureIssueSummary]
    warningSummaries: list[IssueSummary]
    testWarningSummaries: list[TestIssueSummary]


class SourceCodeFrame(XcresultObject):
    """Generated from xcresulttool format description.

    - SourceCodeFrame
      * Kind: object
      * Properties:
        + addressString: String?
        + symbolInfo: SourceCodeSymbolInfo?
    """

    addressString: str | None
    symbolInfo: SourceCodeSymbolInfo | None


class ActionResult(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionResult
      * Kind: object
      * Properties:
        + resultName: String
        + status: String
        + metrics: ResultMetrics
        + issues: ResultIssueSummaries
        + coverage: CodeCoverageInfo
        + timelineRef: Reference?
        + logRef: Reference?
        + testsRef: Reference?
        + diagnosticsRef: Reference?
        + consoleLogRef: Reference?
    """

    resultName: str
    status: str
    metrics: ResultMetrics
    issues: ResultIssueSummaries
    coverage: CodeCoverageInfo
    timelineRef: Reference | None
    logRef: Reference | None
    testsRef: Reference | None
    diagnosticsRef: Reference | None
    consoleLogRef: Reference | None


class ActivityLogCommandInvocationSection(ActivityLogSection):
    """Generated from xcresulttool format description.

    - ActivityLogCommandInvocationSection
      * Supertype: ActivityLogSection
      * Kind: object
      * Properties:
        + commandDetails: String
        + emittedOutput: String
        + exitCode: Int?
    """

    commandDetails: str
    emittedOutput: str
    exitCode: int | None


class ActivityLogMajorSection(ActivityLogSection):
    """Generated from xcresulttool format description.

    - ActivityLogMajorSection
      * Supertype: ActivityLogSection
      * Kind: object
      * Properties:
        + subtitle: String
    """

    subtitle: str


class ActivityLogUnitTestSection(ActivityLogSection):
    """Generated from xcresulttool format description.

    - ActivityLogUnitTestSection
      * Supertype: ActivityLogSection
      * Kind: object
      * Properties:
        + testName: String?
        + suiteName: String?
        + summary: String?
        + emittedOutput: String?
        + performanceTestOutput: String?
        + testsPassedString: String?
        + wasSkipped: Bool
        + runnablePath: String?
        + runnableUTI: String?
    """

    testName: str | None
    suiteName: str | None
    summary: str | None
    emittedOutput: str | None
    performanceTestOutput: str | None
    testsPassedString: str | None
    wasSkipped: bool
    runnablePath: str | None
    runnableUTI: str | None


class SourceCodeContext(XcresultObject):
    """Generated from xcresulttool format description.

    - SourceCodeContext
      * Kind: object
      * Properties:
        + location: SourceCodeLocation?
        + callStack: [SourceCodeFrame]
    """

    location: SourceCodeLocation | None
    callStack: list[SourceCodeFrame]


class ActionRecord(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionRecord
      * Kind: object
      * Properties:
        + schemeCommandName: String
        + schemeTaskName: String
        + title: String?
        + startedTime: Date
        + endedTime: Date
        + runDestination: ActionRunDestinationRecord
        + buildResult: ActionResult
        + actionResult: ActionResult
        + testPlanName: String?
    """

    schemeCommandName: str
    schemeTaskName: str
    title: str | None
    startedTime: datetime.datetime
    endedTime: datetime.datetime
    runDestination: ActionRunDestinationRecord
    buildResult: ActionResult
    actionResult: ActionResult
    testPlanName: str | None


class ActionTestFailureSummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestFailureSummary
      * Kind: object
      * Properties:
        + message: String?
        + fileName: String
        + lineNumber: Int
        + isPerformanceFailure: Bool
        + uuid: String
        + issueType: String?
        + detailedDescription: String?
        + attachments: [ActionTestAttachment]
        + associatedError: TestAssociatedError?
        + sourceCodeContext: SourceCodeContext?
        + timestamp: Date?
        + isTopLevelFailure: Bool
        + expression: TestExpression?
    """

    message: str | None
    fileName: str
    lineNumber: int
    isPerformanceFailure: bool
    uuid: str
    issueType: str | None
    detailedDescription: str | None
    attachments: list[ActionTestAttachment]
    associatedError: TestAssociatedError | None
    sourceCodeContext: SourceCodeContext | None
    timestamp: datetime.datetime | None
    isTopLevelFailure: bool
    expression: TestExpression | None


class ActionTestIssueSummary(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestIssueSummary
      * Kind: object
      * Properties:
        + message: String?
        + fileName: String
        + lineNumber: Int
        + uuid: String
        + issueType: String?
        + detailedDescription: String?
        + attachments: [ActionTestAttachment]
        + associatedError: TestAssociatedError?
        + sourceCodeContext: SourceCodeContext?
        + timestamp: Date?
    """

    message: str | None
    fileName: str
    lineNumber: int
    uuid: str
    issueType: str | None
    detailedDescription: str | None
    attachments: list[ActionTestAttachment]
    associatedError: TestAssociatedError | None
    sourceCodeContext: SourceCodeContext | None
    timestamp: datetime.datetime | None


class ActivityLogTargetBuildSection(ActivityLogMajorSection):
    """Generated from xcresulttool format description.

    - ActivityLogTargetBuildSection
      * Supertype: ActivityLogMajorSection
      * Kind: object
      * Properties:
        + productType: String?
    """

    productType: str | None


class ActionTestExpectedFailure(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestExpectedFailure
      * Kind: object
      * Properties:
        + uuid: String
        + failureReason: String?
        + failureSummary: ActionTestFailureSummary?
        + isTopLevelFailure: Bool
    """

    uuid: str
    failureReason: str | None
    failureSummary: ActionTestFailureSummary | None
    isTopLevelFailure: bool


class ActionTestableSummary(ActionAbstractTestSummary):
    """Generated from xcresulttool format description.

    - ActionTestableSummary
      * Supertype: ActionAbstractTestSummary
      * Kind: object
      * Properties:
        + identifierURL: String?
        + projectRelativePath: String?
        + targetName: String?
        + testKind: String?
        + tests: [ActionTestSummaryIdentifiableObject]
        + diagnosticsDirectoryName: String?
        + failureSummaries: [ActionTestFailureSummary]
        + testLanguage: String?
        + testRegion: String?
    """

    identifierURL: str | None
    projectRelativePath: str | None
    targetName: str | None
    testKind: str | None
    tests: list[ActionTestSummaryIdentifiableObject]
    diagnosticsDirectoryName: str | None
    failureSummaries: list[ActionTestFailureSummary]
    testLanguage: str | None
    testRegion: str | None


class ActionsInvocationRecord(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionsInvocationRecord
      * Kind: object
      * Properties:
        + metadataRef: Reference?
        + metrics: ResultMetrics
        + issues: ResultIssueSummaries
        + actions: [ActionRecord]
        + archive: ArchiveInfo?
    """

    metadataRef: Reference | None
    metrics: ResultMetrics
    issues: ResultIssueSummaries
    actions: list[ActionRecord]
    archive: ArchiveInfo | None


class ActionTestPlanRunSummary(ActionAbstractTestSummary):
    """Generated from xcresulttool format description.

    - ActionTestPlanRunSummary
      * Supertype: ActionAbstractTestSummary
      * Kind: object
      * Properties:
        + testableSummaries: [ActionTestableSummary]
    """

    testableSummaries: list[ActionTestableSummary]


class ActionTestSummary(ActionTestSummaryIdentifiableObject):
    """Generated from xcresulttool format description.

    - ActionTestSummary
      * Supertype: ActionTestSummaryIdentifiableObject
      * Kind: object
      * Properties:
        + testStatus: String
        + duration: Double
        + performanceMetrics: [ActionTestPerformanceMetricSummary]
        + failureSummaries: [ActionTestFailureSummary]
        + expectedFailures: [ActionTestExpectedFailure]
        + skipNoticeSummary: ActionTestNoticeSummary?
        + activitySummaries: [ActionTestActivitySummary]
        + repetitionPolicySummary: ActionTestRepetitionPolicySummary?
        + arguments: [TestArgument]
        + configuration: ActionTestConfiguration?
        + warningSummaries: [ActionTestIssueSummary]
        + summary: String?
        + documentation: [TestDocumentation]
        + trackedIssues: [IssueTrackingMetadata]
        + tags: [TestTag]
    """

    testStatus: str
    duration: float
    performanceMetrics: list[ActionTestPerformanceMetricSummary]
    failureSummaries: list[ActionTestFailureSummary]
    expectedFailures: list[ActionTestExpectedFailure]
    skipNoticeSummary: ActionTestNoticeSummary | None
    activitySummaries: list[ActionTestActivitySummary]
    repetitionPolicySummary: ActionTestRepetitionPolicySummary | None
    arguments: list[TestArgument]
    configuration: ActionTestConfiguration | None
    warningSummaries: list[ActionTestIssueSummary]
    summary: str | None
    documentation: list[TestDocumentation]
    trackedIssues: list[IssueTrackingMetadata]
    tags: list[TestTag]


class ActionTestPlanRunSummaries(XcresultObject):
    """Generated from xcresulttool format description.

    - ActionTestPlanRunSummaries
      * Kind: object
      * Properties:
        + summaries: [ActionTestPlanRunSummary]
    """

    summaries: list[ActionTestPlanRunSummary]


_CURRENT_MODULE = sys.modules[__name__]
_MODEL_NAMES = dir(_CURRENT_MODULE)
_MODEL_NAMES = [m for m in _MODEL_NAMES if not m.startswith("__")]
_RESOLVED_MODELS = [getattr(_CURRENT_MODULE, m) for m in _MODEL_NAMES]
# pylint: disable=unidiomatic-typecheck
_RESOLVED_MODELS = [
    m
    for m in _RESOLVED_MODELS
    if type(m) == type(type) and issubclass(m, XcresultObject)
]
# pylint: enable=unidiomatic-typecheck
MODELS = {m.__name__: m for m in _RESOLVED_MODELS}
